FontInstanceBuilder

Struct FontInstanceBuilder 

pub(crate) struct FontInstanceBuilder {
    instance: FontInstance,
}
Builder for configuring a font instance.

Fields

instance: FontInstance

Implementations

Source

impl FontInstanceBuilder

pub fn size(self, size: Option<f32>) -> FontInstanceBuilder

Sets the size for the font instance, in pixels per em.

Setting this to None disables scaling.

pub fn variations<V>(self, variations: V) -> FontInstanceBuilder

Sets the variations for the font instance from an unordered sequence of variations in user space.

Omitted axes will be set to their default values. Unsupported axes are ignored. If an axis is specified multiple times, the last value is used.

This will overwrite any previous variation settings.

pub fn normalized_coords( self, coords: impl IntoIterator<Item = F2Dot14>, ) -> FontInstanceBuilder

Sets the variations for the font instance from an ordered sequence of normalized coordinates.

If the number of provided coordinates is less than the number of axes, the remaining axes will be set to their default values. If the number of provided coordinates is greater than the number of axes, the extra coordinates will be ignored.

This will overwrite any previous variation settings.

pub fn named_instance(self, index: usize) -> FontInstanceBuilder

Sets the variations for the font instance from a named instance.

If the given named instance index is invalid, then variation settings will be reset to default.

This will overwrite any previous variation settings.

pub fn named_instance_with_overrides<V>( self, index: usize, overrides: V, ) -> FontInstanceBuilder

Sets the variations for the font instance from a named instance, with additional overrides.

If the given named instance index is invalid, then it is ignored and only overrides are applied.

This will overwrite any previous variation settings.

pub fn build(self) -> FontInstance

Builds the font instance.